from PySide2.QtWidgets import QApplication

__title__ = "Variants"
__description__ = "The default view for variants DB"
__long_description__ = """
<p>This window is the main window of Cutevariant. Here you will find the variants
and their related data presented in the various columns selected from the
<em>Fields editor</em> plugin.</p>

You can:

<ul>

<li><b>Set the ACMG score</b> of a variant in 2 clicks via the context menu.</li>

<li><b>Mark one or more variants as favorite(s)</b> so that you can easily find
them later.</li>

<li>Edit/add comments.</li>

<li><b>Consult external databases</b> referencing each selected variant to
quickly obtain additional information.</li>

<li><b>Copy</b> one or more variants into a format that can be used directly in
a Calc/Excel spreadsheet.</li>
</ul>

<p>The displayed variants can be <b>controlled by filters</b> modified in real
time from the <em>Filters Editor</em> plugin or from a VQL query from the 
<em>VQL Editor</em> plugin.</p>

"""
__author__ = "Sacha schutz"
__version__ = "1.0.0"
